@@ -1,3 +1,3 @@
 from .vectors import Vec3, Vec2
-from .matrixes import Mat2
+from .matrixes import Mat2, Mat3, Quat
 from .geometry import Rect, intersect, PolyLine, closest
\ No newline at end of file
